@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:37:05
-@LastEditTime: 2021-10-10 15:38:25
+@LastEditTime: 2022-01-06 17:02:18
 @LastEditors: HuangJianYi
 @Description: 
 """
+from threading import Condition
 from seven_cloudapp_frame.models.ip_base_model import *
 from seven_cloudapp_frame.handlers.frame_base import *
 
@@ -28,5 +29,4 @@ class IpInfoListHandler(ClientBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
-
-        self.response_json_success(IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index))
+        self.response_json_success(IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, condition="is_release=1"))
