@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-12-30 13:56:15
+@LastEditTime: 2022-01-20 13:52:56
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -162,9 +162,16 @@ class PrizeOrderListHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=True)
+        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, field, is_search_roster=is_search_roster, is_cache=True, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
