@@ -2,16 +2,20 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2021-11-17 15:13:36
+@LastEditTime: 2022-01-22 11:46:41
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatPayRequest, WeChatPayReponse, WeChatRefundReponse
 from seven_cloudapp_frame.libs.customize.tiktok_helper import TikTokPayRequest, TikTokReponse
+from seven_cloudapp_frame.models.shakeshop_base_model import *
+from seven_cloudapp_frame.models.price_base_model import *
+from seven_cloudapp_frame.models.asset_base_model import *
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.db_models.pay.pay_order_model import *
 from seven_cloudapp_frame.models.db_models.refund.refund_order_model import *
+from seven_cloudapp_frame.models.db_models.third.third_pay_order_model import *
 
 
 class WechatVoucherOrderHandler(ClientBaseHandler):
@@ -51,7 +55,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
             invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == True:
                 pay_notify_url = invoke_result_data.data["pay_notify_url"] if invoke_result_data.data.__contains__("pay_notify_url") else pay_notify_url
-                time_expire = invoke_result_data.data["time_expire"] if invoke_result_data.data.__contains__("time_expire") else str(SevenHelper.get_now_int(1))  #交易结束时间,设置1小时
+                time_expire = invoke_result_data.data["time_expire"] if invoke_result_data.data.__contains__("time_expire") else str(SevenHelper.get_now_int(hours=1))  #交易结束时间,设置1小时
             invoke_result_data = WeChatPayRequest().create_order(pay_order_no, body, total_fee, ip, pay_notify_url, pay_order.open_id, time_expire)
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -388,4 +392,163 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
         except Exception as ex:
             db_transaction.rollback_transaction()
             self.logging_link_error("【抖音退款异步通知数据处理异常】" + traceback.format_exc())
-        return result_data
\ No newline at end of file
+        return result_data
+
+
+class ShakeshopNotifyHandler(FrameBaseHandler):
+    """
+    :description: 抖店异步通知
+    """
+    def post_async(self):
+        """
+        :description:抖店异步通知
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        result = None
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        asset_type = invoke_result_data.data["asset_type"] if invoke_result_data.data.__contains__("asset_type") else 3 #资产类型，默认价格档位
+        goods_id = invoke_result_data.data["goods_id"] if invoke_result_data.data.__contains__("goods_id") else "" #商品id
+        sku_id = invoke_result_data.data["sku_id"] if invoke_result_data.data.__contains__("sku_id") else "" #skuid
+        reward_order_status_list = invoke_result_data.data["reward_order_status_list"] if invoke_result_data.data.__contains__("reward_order_status_list") else [2]  #订单奖励类型，默认2已支付
+        sub_b_type_list = invoke_result_data.data["sub_b_type_list"] if invoke_result_data.data.__contains__("sub_b_type_list") else [] #下单场景，默认全部
+        try:
+            third_pay_order_model = ThirdPayOrderModel(context=self)
+            user_info_model = UserInfoModel(context=self)
+            shop_id = config.get_value("shake_shop")["shop_id"]
+            app_key = config.get_value("shake_shop")["app_key"]
+            app_secret = config.get_value("shake_shop")["app_secret"]
+            shakeshop_base_model = ShakeShopBaseModel(self, app_key, app_secret, "SELF", None, shop_id)
+            result = shakeshop_base_model.callback(self.request.headers, self.request.body, is_log=False)
+            if result:
+                result = result[0]
+                result["data"] = json.loads(result["data"])
+                if str(result["data"]["shop_id"]) != str(shop_id):
+                    return self.write({'code': 0, 'msg': 'success'})
+                tag = result.get('tag')
+                if tag == '0':  # 抖店推送服务验证消息，需立即返回success
+                    return self.write({'code': 0, 'msg': 'success'})
+                if tag == '101':  # 订单支付成功，根据推送的消息参数进行必要的业务处理，5秒内返回success
+                    params = {}
+                    params["shop_order_id"] = result["data"]["p_id"] #店铺订单编号
+                    order_detail_result = shakeshop_base_model.request(path="/order/orderDetail", params=params, is_log=False)
+                    if order_detail_result and order_detail_result["code"] == 10000:
+                        open_id = order_detail_result["data"]["shop_order_detail"]["open_id"]
+                        user_info_dict = user_info_model.get_cache_dict("open_id=%s", limit="1", order_by="id desc", params=[open_id])
+                        if user_info_dict:
+                            tiktok_goods_id_list = []
+                            if asset_type == 3:
+                                price_base_model = PriceBaseModel(context=self.context)
+                                price_gear_dict_list = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0).data
+                                for price_gear_dict in price_gear_dict_list:
+                                    tiktok_goods_id_list.append(price_gear_dict["goods_id"])
+                            else:
+                                tiktok_goods_id_list.append(str(goods_id))
+                            pay_order_no_list, redis_init, pay_order_cache_key = self.get_pay_order_no_list(user_info_dict["app_id"], user_info_dict["user_id"])
+                            third_pay_order_list = []
+                            total_buy_num = 0
+                            total_pay_price = 0
+                            for sku_order in order_detail_result["data"]["shop_order_detail"]["sku_order_list"]:
+                                asset_object_id = ""
+                                if len(sub_b_type_list) > 0 and sku_order["sub_b_type"] not in sub_b_type_list:
+                                    continue
+                                if str(sku_order["product_id"]) in tiktok_goods_id_list and sku_order["order_status"] in reward_order_status_list and sku_order["order_id"] not in pay_order_no_list:
+                                    if asset_type == 3:
+                                        now_price_gear_dict = None
+                                        for price_gear_dict in price_gear_dict_list:
+                                            if (price_gear_dict["effective_date"] == '1900-01-01 00:00:00' or TimeHelper.format_time_to_datetime(price_gear_dict["effective_date"]) < TimeHelper.format_time_to_datetime(TimeHelper.timestamp_to_format_time(sku_order["pay_time"]))) and price_gear_dict["goods_id"] == str(sku_order["product_id"]):
+                                                #关联类型：1商品skuid关联2商品id关联
+                                                if price_gear_dict["relation_type"] == 1 and price_gear_dict["sku_id"] != str(sku_order["sku_id"]):
+                                                    continue
+                                                now_price_gear_dict = price_gear_dict
+                                        if not now_price_gear_dict:
+                                            continue
+                                        asset_object_id = now_price_gear_dict["id"]
+                                    else:
+                                        if str(goods_id) != str(sku_order["product_id"]):
+                                            continue
+                                        if sku_id and str(sku_id) != str(sku_order["sku_id"]):
+                                            continue
+                                    third_pay_order = ThirdPayOrder()
+                                    third_pay_order.app_id = user_info_dict["app_id"]
+                                    third_pay_order.act_id = user_info_dict["act_id"]
+                                    third_pay_order.user_id = user_info_dict["user_id"]
+                                    third_pay_order.open_id = open_id
+                                    third_pay_order.user_nick = user_info_dict["user_nick"]
+                                    third_pay_order.goods_code = sku_order["product_id"]
+                                    third_pay_order.goods_name = sku_order["product_name"]
+                                    third_pay_order.order_status = sku_order["order_status"]
+                                    third_pay_order.sku_id = sku_order["sku_id"]
+                                    third_pay_order.sku_name = json.dumps(sku_order["spec"])
+                                    third_pay_order.buy_num = sku_order["item_num"]
+                                    third_pay_order.pay_price = decimal.Decimal(sku_order["pay_amount"] / 100)
+                                    third_pay_order.main_pay_order_no = sku_order["parent_order_id"]
+                                    third_pay_order.sub_pay_order_no = sku_order["order_id"]
+                                    third_pay_order.pay_date = TimeHelper.timestamp_to_format_time(sku_order["pay_time"])
+                                    third_pay_order.asset_type = asset_type
+                                    third_pay_order.asset_object_id = asset_object_id
+                                    third_pay_order.surplus_count = sku_order["item_num"]
+                                    third_pay_order.create_date = SevenHelper.get_now_datetime()
+                                    total_buy_num += int(sku_order["item_num"])
+                                    total_pay_price += decimal.Decimal(sku_order["pay_amount"] / 100)
+                                    third_pay_order_list.append(third_pay_order)
+                            if len(third_pay_order_list) > 0:
+                                third_pay_order_result = third_pay_order_model.add_list(third_pay_order_list)
+                                if third_pay_order_result == True and total_buy_num > 0:
+                                    #更新用户表
+                                    user_info_model.update_table("pay_price=pay_price+%s,pay_num=pay_num+%s", "user_id=%s", params=[total_pay_price, total_buy_num, user_info_dict["user_id"]])
+                                    asset_base_model = AssetBaseModel(context=self)
+                                    for item in third_pay_order_list:
+                                        only_id = str(item.sub_pay_order_no)
+                                        asset_invoke_result_data = asset_base_model.update_user_asset(user_info_dict["app_id"], user_info_dict["act_id"], 0, user_info_dict["user_id"], user_info_dict["open_id"], user_info_dict["user_nick"], item.asset_type, item.buy_num, item.asset_object_id, 1, "", "", "抖店购买", only_id, self.__class__.__name__, self.request_code, info_json={})
+                                        if asset_invoke_result_data.success == True:
+                                            redis_init.lpush(pay_order_cache_key, item.sub_pay_order_no)
+                                            redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
+                                    self.business_process_executed(third_pay_order_list, ref_params={"total_buy_num": total_buy_num, "total_pay_price": total_pay_price, "sku_order_list": order_detail_result["data"]["shop_order_detail"]["sku_order_list"]})
+                    else:
+                        self.logging_link_info("【抖店异步通知结果】" + str(result) + ":" + str(order_detail_result))
+                return self.write({'code': 0, 'msg': 'success'})
+            else:
+                return self.write({'code': 40041, 'message': '解析推送数据失败'})
+        except Exception as ex:
+            self.logging_link_error("【抖店异步通知】" + traceback.format_exc() + ":" + str(result))
+            return self.write({'code': 40041, 'message': '解析推送数据失败'})
+
+    def business_process_executed(self, result_data, ref_params):
+        """
+        :description: 执行后事件
+        :param result_data: result_data
+        :param ref_params: 关联参数
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return result_data
+
+    def get_pay_order_no_list(self,app_id,user_id):
+        """
+        :description: 获取已获取奖励的订单子编号列表
+        :param app_id:应用标识
+        :param user_id:用户标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        redis_init = SevenHelper.redis_init()
+        pay_order_cache_key = f"sub_pay_order_no_list:appid_{app_id}_userid_{user_id}"
+        pay_order_no_list = redis_init.lrange(pay_order_cache_key,0,-1)
+        pay_order_list = []
+        is_add = False
+        if not pay_order_no_list or len(pay_order_no_list)<=0:
+            third_pay_order_model = ThirdPayOrderModel(context=self)
+            pay_order_list = third_pay_order_model.get_dict_list("app_id=%s and user_id=%s", field="sub_pay_order_no", params=[app_id, user_id])
+            is_add = True
+        if len(pay_order_list) >0:
+            for item in pay_order_list:
+                pay_order_no_list.append(item["sub_pay_order_no"])
+                if is_add == True:
+                    redis_init.lpush(pay_order_cache_key,item["sub_pay_order_no"])
+                    redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
+        return pay_order_no_list,redis_init,pay_order_cache_key
\ No newline at end of file
