@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-01-04 17:02:52
+@LastEditTime: 2022-01-26 17:16:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -65,10 +65,12 @@ class LoginHandler(ClientBaseHandler):
             open_id = invoke_result_data.data["openid"]
 
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, self.emoji_to_emoji_base64(user_nick), avatar)
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data.data["user_nick"] = self.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
+        if invoke_result_data.data["user_nick_encrypt"]:
+            invoke_result_data.data["user_nick"] = CryptographyHelper.base64_decrypt(invoke_result_data.data["user_nick_encrypt"])
         ref_params = {}
         ref_params["app_id"] = app_id
         ref_params["act_id"] = act_id
@@ -123,7 +125,7 @@ class UpdateUserInfoHandler(ClientBaseHandler):
 
         invoke_result_data = InvokeResultData()
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.update_user_info(app_id, act_id, user_id, open_id, self.emoji_to_emoji_base64(user_nick), avatar, is_member_before, is_favor_before)
+        invoke_result_data = user_base_model.update_user_info(app_id, act_id, user_id, open_id, user_nick, avatar, is_member_before, is_favor_before)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         else:
@@ -238,7 +240,7 @@ class GetCouponPrizeHandler(ClientBaseHandler):
         if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
             return self.response_json_error("error", "奖品不存在")
         tao_coupon_model = TaoCouponModel(context=self)
-        tao_coupon_dict = tao_coupon_model.get_dict(where="prize_id=%s", params=[prize_roster_dict["prize_id"]])
+        tao_coupon_dict = tao_coupon_model.get_dict(where="prize_id=%s", limit="1", params=[prize_roster_dict["prize_id"]])
         if not tao_coupon_dict or tao_coupon_dict['right_ename'] == "":
             return self.response_json_error("error", "奖品不是优惠券,无需领取")
         top_base_model = TopBaseModel(context=self)
