@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-01-14 14:13:25
+@LastEditTime: 2022-02-21 10:38:06
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -107,13 +107,14 @@ class FrameBaseHandler(BaseApiHandler):
             param_ret = self.get_argument(param_name, default, strip=strip)
         if param_ret == "" or param_ret == "undefined":
             param_ret = default
+        param_ret = StringHelper.filter_routine_key(param_ret)
         if filter_sql == True:
             param_ret = StringHelper.filter_sql(param_ret)
         if filter_special_key == True:
             param_ret = StringHelper.filter_special_key(param_ret)
         return param_ret
 
-    def get_param_int(self, param_name, default="", strip=True, filter_sql=False, filter_special_key=False):
+    def get_param_int(self, param_name, default=0, strip=True, filter_sql=False, filter_special_key=False):
         """
         :description: 二次封装获取参数转整形
         :param param_name: 参数名
@@ -142,6 +143,8 @@ class FrameBaseHandler(BaseApiHandler):
         is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
         if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
             encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
+            if hasattr(self, "encrypt_key"):
+                encrypt_key = self.encrypt_key
             #当有参数app_id时，优先取app_id，然后在是source_app_id
             if self.get_argument("app_id", "", strip=True):
                 app_id = self.get_argument("app_id", "", strip=True)
@@ -187,11 +190,11 @@ class FrameBaseHandler(BaseApiHandler):
             if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 try:
                     json_params = json.loads(self.request.body)
+                    if json_params:
+                        for field in json_params:
+                            self.request_params[field] = json_params[field]
                 except:
                     pass
-                if json_params:
-                    for field in json_params:
-                        self.request_params[field] = json_params[field]
             else:
                 for field in self.request.arguments:
                     self.request_params[field] = self.get_argument(field, "", strip=True)
@@ -334,8 +337,6 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         result = False, ""
-        if config.get_value("is_pressure_test",False): #是否进行压力测试
-            return result
         if object_id and handler_name and app_id:
             sign = self.get_signature_md5(self.request_params)
             if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
@@ -482,9 +483,9 @@ class FrameBaseHandler(BaseApiHandler):
         :return str
         :last_editors: HuangJianYi
         """
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_param_int("tb_user_id")
         if user_id == 0:
-            user_id = int(self.get_param("user_id", 0))
+            user_id = self.get_param_int("user_id")
         return user_id
 
     def get_source_app_id(self):
@@ -499,7 +500,7 @@ class FrameBaseHandler(BaseApiHandler):
             return source_app_id
         source_app_id = self.get_param("source_app_id")
         #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
-        if source_app_id == config.get_value("client_template_id"):
+        if source_app_id == config.get_value("client_template_id") or source_app_id == "":
             source_app_id = config.get_value("test_source_app_id")
         return source_app_id
 
@@ -517,7 +518,7 @@ class FrameBaseHandler(BaseApiHandler):
             if user_nick and plat_type == 1:
                 store_user_nick = user_nick.split(':')[0]
                 if store_user_nick:
-                    app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", field="app_id", params=store_user_nick)
+                    app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
                     if app_info_dict:
                         app_id = app_info_dict["app_id"]
         return app_id
@@ -690,8 +691,8 @@ class ClientBaseHandler(FrameBaseHandler):
             info_model = parse_qs(clientheaderinfo_string)
             device_info_dict["pid"] = int(info_model["pid"][0])  # 产品标识
             device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0])  # 渠道标识
-            device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(info_model["height"][0])  # 高度
-            device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(info_model["width"][0])  # 宽度
+            device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(float(info_model["height"][0]))  # 高度
+            device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(float(info_model["width"][0]))  # 宽度
             device_info_dict["version"] = "" if "version" not in info_model.keys() else info_model["version"][0]  # 客户端版本号
             device_info_dict["app_version"] = "" if "app_version" not in info_model.keys() else info_model["app_version"][0]  # 小程序版本号
             device_info_dict["net"] = "" if "net" not in info_model.keys() else info_model["net"][0]  # 网络
@@ -709,11 +710,7 @@ class ClientBaseHandler(FrameBaseHandler):
         :return: 解密后的表情字符串
         :last_editors: HuangJianYi 
         """
-        results = re.findall('\[em_(.*?)\]', text_str)
-        if results:
-            for item in results:
-                text_str = str(text_str).replace("[em_{0}]".format(item), CryptographyHelper.base64_decrypt(item))
-        return text_str
+        return CryptographyHelper.emoji_base64_to_emoji(text_str)
 
     def emoji_to_emoji_base64(self, text_str):
         """
@@ -723,14 +720,7 @@ class ClientBaseHandler(FrameBaseHandler):
         :return: 解密后的表情字符串
         :last_editors: HuangJianYi 
         """
-        list_e = []
-        for i in text_str:
-            list_e.append(i)
-        for location, item_emoji in enumerate(text_str):
-            if item_emoji in unicode_codes.UNICODE_EMOJI["en"]:
-                emoji_base64 = CryptographyHelper.base64_encrypt(item_emoji, "utf-8")
-                list_e[location] = "[em_" + emoji_base64 + "]"
-        return "".join(list_e)
+        return CryptographyHelper.emoji_to_emoji_base64(text_str)
 
 
 def filter_check_params(must_params=None):
