@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-12-22 16:38:43
+@LastEditTime: 2022-01-21 21:27:46
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -37,7 +37,7 @@ class ActTypeListHandler(ClientBaseHandler):
             act_type.type_desc = self.json_loads(act_type.type_desc) if act_type.type_desc else []
             act_type.task_asset_type_json = self.json_loads(act_type.task_asset_type_json) if act_type.task_asset_type_json else []
             if is_act > 0 and app_id:
-                act_dict = ActInfoModel(context=self).get_cache_dict("app_id=%s and act_type=%s", field="id", params=[app_id, act_type.id])
+                act_dict = ActInfoModel(context=self).get_cache_dict("app_id=%s and act_type=%s", limit="1", field="id", params=[app_id, act_type.id])
                 if act_dict:
                     act_type.act_id = act_dict['id']
                 else:
