@@ -2,13 +2,15 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2021-12-27 20:12:36
+@LastEditTime: 2022-02-24 16:36:46
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.app_base_model import *
+from seven_cloudapp_frame.models.mp_base_model import *
+from asq.initiators import query
 
 
 class InstantiateAppHandler(ClientBaseHandler):
@@ -137,7 +139,27 @@ class AppInfoHandler(ClientBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class GetAppIDHandler(ClientBaseHandler):
+class CheckGmPowerHandler(ClientBaseHandler):
+    """
+    :description: 获取是否有GM工具权限
+    """
+    def get_async(self):
+        """
+        :description: 获取是否有GM工具权限
+        :param 
+        :return: True是 False否
+        :last_editors: HuangJianYi
+        """
+        is_power = False
+        store_user_nick = self.get_user_nick().split(':')[0]
+        if not store_user_nick:
+            return self.response_json_success(is_power)
+        if store_user_nick == config.get_value("test_user_nick"):
+            is_power = True
+        return self.response_json_success(is_power)
+
+
+class GetAppidByGmHandler(ClientBaseHandler):
     """
     :description: 获取应用标识
     """
@@ -149,9 +171,15 @@ class GetAppIDHandler(ClientBaseHandler):
         :return app_id
         :last_editors: HuangJianYi
         """
-        store_name = self.get_param("store_name")
-        app_base_model = AppBaseModel(context=self)
-        return self.response_json_success(app_base_model.get_app_id(store_name))
+        app_id = ""
+        store_user_nick = self.get_user_nick().split(':')[0]
+        if not store_user_nick:
+            return self.response_json_success(app_id)
+        if store_user_nick == config.get_value("test_user_nick"):
+            store_name = self.get_param("store_name")
+            app_base_model = AppBaseModel(context=self)
+            app_id = app_base_model.get_app_id(store_name)
+        return self.response_json_success(app_id)
 
 
 class GetShortUrlHandler(ClientBaseHandler):
@@ -177,3 +205,55 @@ class GetShortUrlHandler(ClientBaseHandler):
             return self.response_json_success("")
         else:
             return self.response_json_success(invoke_result_data.data)
+
+
+class GetHighPowerListHandler(ClientBaseHandler):
+    """
+    :description: 获取中台配置的高级权限列表
+    """
+    def get_async(self):
+        """
+        :description: 获取中台配置的高级权限列表
+        :return: list
+        :last_editors: HuangJianYi
+        """
+        user_nick = self.get_user_nick()
+        if not user_nick:
+            return self.response_json_error("Error", "对不起,请先授权登录")
+        store_user_nick = user_nick.split(':')[0]
+        access_token = self.get_param("access_token")
+        top_base_model = TopBaseModel(context=self)
+        mp_base_model = MPBaseModel(context=self)
+        custom_function_list = mp_base_model.get_custom_function_list(store_user_nick)
+        config_data_list = []
+        if len(custom_function_list) == 0:
+            config_data = {}
+            config_data["is_customized"] = 0
+            config_data["name"] = ""
+            config_data["project_code"] = ""
+            config_data["cloud_app_id"] = 0
+            config_data["function_config_list"] = []
+            config_data["skin_config_list"] = []
+            app_key, app_secret = self.get_app_key_secret()
+            #获取项目编码
+            project_code = top_base_model.get_project_code(store_user_nick, access_token, app_key, app_secret)
+            public_function_list = mp_base_model.get_public_function_list(project_code)
+            if len(public_function_list) > 0:
+                config_data["function_config_list"] = query(public_function_list[0]["function_info_second_list"]).select(lambda x: {"name": x["name"], "key_name": x["key_name"]}).to_list()
+                config_data["skin_config_list"] = query(public_function_list[0]["skin_ids_second_list"]).select(lambda x: {"name": x["name"], "theme_id": x["theme_id"]}).to_list()
+                config_data["name"] = public_function_list[0]["name"]
+                config_data["project_code"] = public_function_list[0]["project_code"]
+            config_data_list.append(config_data)
+        else:
+            for custom_function in custom_function_list:
+                config_data = {}
+                config_data["is_customized"] = 1
+                config_data["name"] = "定制版"
+                config_data["project_code"] = ""
+                config_data["cloud_app_id"] = custom_function["cloud_app_id"]
+                config_data["function_config_list"] = query(custom_function["function_info_second_list"]).select(lambda x: {"name": x["name"], "key_name": x["key_name"]}).to_list()
+                config_data["skin_config_list"] = query(custom_function["skin_ids_second_list"]).select(lambda x: {"name": x["name"], "theme_id": x["theme_id"]}).to_list()
+                config_data["module_name"] = custom_function["module_name"]
+                config_data["module_pic"] = custom_function["module_pic"]
+                config_data_list.append(config_data)
+        self.response_json_success(config_data_list)
\ No newline at end of file
