@@ -2,12 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2021-12-29 15:32:27
+@LastEditTime: 2022-02-18 14:13:24
 @LastEditors: HuangJianYi
 @Description: 基础模块
 """
+
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.enum import *
+from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.cms_base_model import *
 from seven_cloudapp_frame.models.db_models.cms.cms_info_model import *
@@ -51,31 +53,6 @@ class FriendLinkListHandler(ClientBaseHandler):
         return self.response_json_success(friend_link_list)
 
 
-class SaasCustomHandler(ClientBaseHandler):
-    """
-    :description: saas定制化信息获取
-    """
-    def get_async(self):
-        """
-        :description: saas定制化信息获取
-        :param {*}
-        :return int
-        :last_editors: HuangJianYi
-        """
-        user_nick = self.get_user_nick()
-        if not user_nick:
-            return self.response_json_success(0)
-        store_user_nick = user_nick.split(':')[0]
-        if not store_user_nick:
-            return self.response_json_success(0)
-        cloud_app_id = 0
-        saas_custom = SaasCustomModel(context=self).get_entity("store_user_nick=%s AND is_release=1", params=store_user_nick)
-        if saas_custom:
-            cloud_app_id = saas_custom.cloud_app_id
-
-        return self.response_json_success(cloud_app_id)
-
-
 class SendSmsHandler(ClientBaseHandler):
     """
     :description: 发送短信
@@ -227,7 +204,7 @@ class GetProductPriceHandler(ClientBaseHandler):
         """
         product_price_model = ProductPriceModel(context=self)
         now_date = SevenHelper.get_now_datetime()
-        product_price = product_price_model.get_dict(where="%s>=begin_time and %s<=end_time and is_release=1", order_by="create_time desc", params=[now_date, now_date])
+        product_price = product_price_model.get_dict(where="%s>=begin_time and %s<=end_time and is_release=1", order_by="create_time desc", limit="1", params=[now_date, now_date])
         if not product_price:
             return self.response_json_error("error", "找不到产品价格信息")
         try:
@@ -235,4 +212,5 @@ class GetProductPriceHandler(ClientBaseHandler):
         except:
             return self.response_json_error("error", "产品价格信息格式有误")
 
-        return self.reponse_json_success(product_price)
\ No newline at end of file
+        return self.reponse_json_success(product_price)
+
