@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-12-30 14:09:13
+@LastEditTime: 2022-01-20 14:10:36
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -128,9 +128,10 @@ class PrizeOrderListHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params)
+        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
@@ -245,8 +246,11 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
         order_base_model = OrderBaseModel(context=self)
-        invoke_result_data = order_base_model.update_prize_order_status(app_id, prize_order_id, order_status, express_company, express_no)
+        invoke_result_data = order_base_model.update_prize_order_status(app_id, prize_order_id, order_status, express_company, express_no, prize_roster_sub_table)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -281,8 +285,11 @@ class ImportPrizeOrderHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
         order_base_model = OrderBaseModel(context=self)
-        invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content_type, content, ref_head_name)
+        invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content_type, content, ref_head_name, prize_roster_sub_table)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -341,17 +348,18 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = []
         if page_size <= 500:
-            prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params).data
+            prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table).data
         else:
             max_page_size = 100
             repeat_count = page_size // max_page_size  # 循环次数
             begin_page_index = page_index * repeat_count  # 开始页码
             for i in range(repeat_count):
-                list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params).data
+                list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table).data
                 if len(list_dict) <= 0:
                     break
                 prize_order_list_dict.extend(list_dict)
