@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-10-08 22:01:47
-@LastEditTime: 2021-10-15 14:59:20
+@LastEditTime: 2022-01-26 17:11:30
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -18,6 +18,39 @@ class CryptographyHelper:
     :return: 
     :last_editors: HuangJianYi
     """
+
+    @classmethod
+    def emoji_base64_to_emoji(self, text_str):
+        """
+        :description: 把加密后的表情还原
+        :param text_str: 加密后的字符串
+        :return: 解密后的表情字符串
+        :last_editors: HuangJianYi 
+        """
+        results = re.findall('\[em_(.*?)\]', text_str)
+        if results:
+            for item in results:
+                text_str = str(text_str).replace("[em_{0}]".format(item), self.base64_decrypt(item))
+        return text_str
+
+    @classmethod
+    def emoji_to_emoji_base64(self, text_str):
+        """
+        :description: emoji表情转为[em_xxx]形式存于数据库,打包每一个emoji
+        :description: 性能遇到问题时重新设计转换程序
+        :param text_str: 未加密的字符串
+        :return: 解密后的表情字符串
+        :last_editors: HuangJianYi 
+        """
+        list_e = []
+        for i in text_str:
+            list_e.append(i)
+        for location, item_emoji in enumerate(text_str):
+            if item_emoji in unicode_codes.UNICODE_EMOJI["en"]:
+                emoji_base64 = self.base64_encrypt(item_emoji, "utf-8")
+                list_e[location] = "[em_" + emoji_base64 + "]"
+        return "".join(list_e)
+
     @classmethod
     def base64_encrypt(self, source, encoding="utf-8"):
         """
