@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-01-07 15:43:42
+@LastEditTime: 2022-01-22 11:44:56
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -44,6 +44,8 @@ class SevenHelper:
         :return: bool true-代表连续请求进行限制，false-代表跳过限制
         :last_editors: HuangJianYi
         """
+        if config.get_value("is_pressure_test",False): #是否进行压力测试
+            return False
         redis_init = self.redis_init()
         post_value = redis_init.get(cache_key)
         if post_value == None:
@@ -99,7 +101,7 @@ class SevenHelper:
         :param lock_name：锁定名称
         :param acquire_time: 客户端等待获取锁的时间,单位秒
         :param time_out: 锁的超时时间,单位秒
-        :return bool
+        :return 分布式锁是否获得（True获得False未获得）和解锁钥匙（释放锁时需传入才能解锁成功）
         :last_editors: HuangJianYi
         """
         identifier = str(uuid.uuid4())
@@ -344,15 +346,16 @@ class SevenHelper:
         return TimeHelper.add_hours_by_format_time(hour=add_hours)
 
     @classmethod
-    def get_now_int(self, hours=0,fmt='%Y%m%d%H%M%S'):
+    def get_now_int(self, hours=0, minutes=0, fmt='%Y%m%d%H%M%S'):
         """
         :description: 获取整形的时间 格式为yyyyMMddHHmmss，如2009年12月27日9点10分10秒表示为20091227091010
         :param hours: 需要增加的小时数
+        :param hours: 需要增加的分钟数
         :param fmt: 时间格式
         :return:
         :last_editors: HuangJianYi
         """
-        now_date = (datetime.datetime.now() + datetime.timedelta(hours=hours))
+        now_date = (datetime.datetime.now() + datetime.timedelta(minutes=minutes, hours=hours))
         return int(now_date.strftime(fmt))
 
     @classmethod
