@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-01-05 17:59:45
+@LastEditTime: 2022-01-10 13:57:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -98,7 +98,7 @@ class WeChatHelper:
             'secret': app_secret,
             'grant_type': grant_type,
         }
-        respone = None
+        response = None
         redis_init = SevenHelper.redis_init()
         redis_key = f"wechat_access_token:{str(app_id)}"
         try:
@@ -107,14 +107,14 @@ class WeChatHelper:
                 invoke_result_data.data = access_token
                 return invoke_result_data
             requset_url = 'https://api.weixin.qq.com/cgi-bin/token'
-            respone = requests.get(requset_url, params=param)
-            respone_data = SevenHelper.json_loads(respone.text)
-            if respone_data.__contains__("errcode") and respone_data["errcode"] != 0:
+            response = requests.get(requset_url, params=param)
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
                 invoke_result_data.success = False
-                invoke_result_data.error_code = respone_data["errcode"]
-                invoke_result_data.error_message = respone_data["errmsg"]
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
                 return invoke_result_data
-            invoke_result_data.data = str(respone_data["access_token"])
+            invoke_result_data.data = str(response_data["access_token"])
             redis_init.set(redis_key, invoke_result_data.data, ex=3600)
             return invoke_result_data
         except Exception as ex:
