@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-11-25 11:14:04
+@LastEditTime: 2022-01-13 14:48:28
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -20,8 +20,10 @@ class ActBaseModel():
     """
     :description: 活动信息业务模型
     """
-    def __init__(self, context):
+    def __init__(self,context=None,logging_error=None,logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def _delete_act_info_dependency_key(self,app_id,act_id):
         """
