@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-01-13 14:49:03
+@LastEditTime: 2022-01-21 21:28:11
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -35,7 +35,7 @@ class AppBaseModel():
         :last_editors: HuangJianYi
         """
         app_id = ""
-        app_info_dict = AppInfoModel(context=self.context).get_cache_dict("store_name=%s", field="app_id", params=[store_name])
+        app_info_dict = AppInfoModel(context=self.context).get_cache_dict("store_name=%s", limit="1", field="app_id", params=[store_name])
         if app_info_dict:
             app_id = app_info_dict["app_id"]
         return app_id
@@ -51,9 +51,9 @@ class AppBaseModel():
         app_info_model = AppInfoModel(context=self.context)
         if is_cache:
             dependency_key = f"app_info:appid_{app_id}"
-            return app_info_model.get_cache_dict(dependency_key=dependency_key,where="app_id=%s", params=[app_id])
+            return app_info_model.get_cache_dict(dependency_key=dependency_key, limit="1", where="app_id=%s", params=[app_id])
         else:
-            return app_info_model.get_dict(where="app_id=%s", params=[app_id])
+            return app_info_model.get_dict(where="app_id=%s", limit="1", params=[app_id])
 
     def get_app_expire(self,app_id):
         """
