@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2022-01-13 14:31:54
+@LastEditTime: 2022-02-25 09:44:51
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -60,6 +60,26 @@ class AssetBaseModel():
             redis_init.hincrby(hash_name_2, str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M')), 1)
             redis_init.expire(hash_name_2, 24 * 3600)
 
+    def delete_asset_only(self, act_id, only_id, create_day=0):
+        """
+        :description: 清除资产唯一标识 从数据库和redis中删除
+        :param act_id：活动标识
+        :param only_id：资产唯一标识
+        :param create_day：整形的创建天20200506
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        redis_init = SevenHelper.redis_init()
+        hash_name = f"asset_only_list:{act_id}"
+        if create_day <= 0:
+            hash_name += f"_{SevenHelper.get_now_day_int()}"
+        else:
+            hash_name += f"_{create_day}"
+        if redis_init.hexists(hash_name, only_id):
+            redis_init.hdel(hash_name, only_id)
+            asset_only_model = AssetOnlyModel(context=self.context)
+            asset_only_model.del_entity("only_id=%s", params=[only_id])
+
     def get_user_asset_id_md5(self, act_id, user_id, asset_type, asset_object_id):
         """
         :description: 生成用户资产唯一标识
@@ -246,11 +266,15 @@ class AssetBaseModel():
                 asset_only_model.add_entity(asset_only)
             asset_log_model.add_entity(asset_log)
 
-            result = db_transaction.commit_transaction()
+            result,message = db_transaction.commit_transaction(return_detail_tuple=True)
             if not result:
                 if only_id:
                     #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
                     self._add_onlyid_warn_stat(handler_name)
+                if self.context:
+                    self.context.logging_link_error("【变更资产】" + message)
+                elif self.logging_link_error:
+                    self.logging_link_error("【变更资产】" + message)
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "fail"
@@ -324,10 +348,11 @@ class AssetBaseModel():
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
             for user_asset_dict in user_asset_dict_list:
-                if user_asset_dict["app_id"] != str(app_id):
-                    user_asset_dict["asset_value"] = 0
-                if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
-                    user_asset_dict["asset_value"] = 0
+                if config.get_value("is_check_asset",True) == True: #是否开启资产校验
+                    if user_asset_dict["app_id"] != str(app_id):
+                        user_asset_dict["asset_value"] = 0
+                    if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
+                        user_asset_dict["asset_value"] = 0
         return user_asset_dict_list
 
     def get_user_asset(self, app_id, act_id, user_id, asset_type, asset_object_id):
@@ -346,12 +371,13 @@ class AssetBaseModel():
         sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
         user_asset_model = UserAssetModel(sub_table=sub_table, context=self.context)
         user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
-        user_asset_dict = user_asset_model.get_dict("id_md5=%s",params=[user_asset_id_md5])
+        user_asset_dict = user_asset_model.get_dict("id_md5=%s", limit="1", params=[user_asset_id_md5])
         if user_asset_dict:
-            if user_asset_dict["app_id"] != str(app_id):
-                user_asset_dict["asset_value"] = 0
-            if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
-                user_asset_dict["asset_value"] = 0
+            if config.get_value("is_check_asset",True) == True: #是否开启资产校验
+                if user_asset_dict["app_id"] != str(app_id):
+                    user_asset_dict["asset_value"] = 0
+                if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
+                    user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
     def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1):
@@ -383,9 +409,6 @@ class AssetBaseModel():
         condition = "act_id=%s AND asset_type=%s"
         params = [act_id, asset_type]
 
-        if app_id:
-            condition += " AND app_id=%s"
-            params.append(app_id)
         if user_id != 0:
             condition += " AND user_id=%s"
             params.append(user_id)
@@ -426,6 +449,8 @@ class AssetBaseModel():
             page_list, total = asset_log_model.get_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params)
         if len(page_list) > 0:
             for item in page_list:
+                if item["app_id"] != app_id:
+                    return page_info
                 item["create_day"] = TimeHelper.format_time_to_datetime(str(item["create_date"])).strftime('%Y-%m-%d')
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
@@ -454,9 +479,6 @@ class AssetBaseModel():
 
         condition = "act_id=%s and asset_type=%s"
         params = [act_id, asset_type]
-        if app_id:
-            condition += " AND app_id=%s"
-            params.append(app_id)
         if asset_type != 0:
             condition += " AND asset_type=%s"
             params.append(asset_type)
@@ -480,5 +502,9 @@ class AssetBaseModel():
             params.append(end_date)
 
         page_list, total = AssetWarnNoticeModel(context=self.context).get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)
+        if len(page_list) > 0:
+            for item in page_list:
+                if item["app_id"] != app_id:
+                    return page_info
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
\ No newline at end of file
