@@ -2,9 +2,9 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2022-01-06 19:06:31
+@LastEditTime: 2022-02-24 13:41:30
 @LastEditors: HuangJianYi
-:Description: 数据库基础操作类
+:Description: 数据缓存业务模型
 """
 import json
 from copy import deepcopy
@@ -17,7 +17,7 @@ class CacheModel(BaseModel):
 
     def __init__(self, model_class, sub_table):
         """
-        :Description: 数据缓存业务模型
+        :Description: 数据缓存业务模型,用于mysql数据同步到redis
         :param model_class: 实体对象类
         :param sub_table: 分表标识
         :last_editors: HuangJianYi
@@ -137,15 +137,30 @@ class CacheModel(BaseModel):
         redis_cli = RedisHelper.redis_init(host, port, db, password, decode_responses=decode_responses)
         return redis_cli
 
-    def delete_dependency_key(self, dependency_key=''):
+    def delete_dependency_key(self, dependency_key='', delay_delete_time=0.1):
         """
-        :Description: 删除依赖键
+        :Description: 删除依赖键,支持延迟删除和重试机制
         :param dependency_key: 依赖键,为空则删除默认依赖建
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        redis_init = self.__redis_init()
-        return redis_init.delete(self.__get_dependency_key(dependency_key))
+        count = 0
+        while count <= 2:
+            count += 1
+            try:
+                redis_init = self.__redis_init()
+                if delay_delete_time > 0:
+                    time.sleep(delay_delete_time)
+                if isinstance(dependency_key,list):
+                    for key in dependency_key:
+                        redis_init.delete(self.__get_dependency_key(key))
+                else:
+                    redis_init.delete(self.__get_dependency_key(dependency_key))
+                break
+            except:
+                print(traceback.print_exc())
+                pass
 
     def get_cache_list(self, where='', group_by='', order_by='', limit='', field="*", params=None,dependency_key='', cache_expire=600):
         """
@@ -273,7 +288,7 @@ class CacheModel(BaseModel):
         """
         where = f"{self.primary_key_field}=%s"
         params = [primary_key_id]
-        sql = f"SELECT * FROM {self.table_name} WHERE {where};"
+        sql = f"SELECT * FROM {self.table_name} WHERE {where} LIMIT 1;"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "entityone_" + self.table_name + "_" + self.__get_cache_key('*',where,'','','',params)
@@ -322,7 +337,7 @@ class CacheModel(BaseModel):
                 return list_row['count']
             return 0
 
-    def get_cache_dict(self, where='', group_by='', order_by='', limit='', field="*", params=None, dependency_key='', cache_expire=600):
+    def get_cache_dict(self, where='', group_by='', order_by='', limit='1', field="*", params=None, dependency_key='', cache_expire=600):
         """
         :Description: 返回字典dict
         :param dependencyKey: 依赖键
@@ -376,7 +391,7 @@ class CacheModel(BaseModel):
         """
         where = f"{self.primary_key_field}=%s"
         params = [primary_key_id]
-        sql = f"SELECT {field} FROM {self.table_name} WHERE {where};"
+        sql = f"SELECT {field} FROM {self.table_name} WHERE {where} LIMIT 1;"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "dictone_" + self.table_name + "_" + self.__get_cache_key(field,where,'','','',params)
