@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2022-01-11 18:04:29
+@LastEditTime: 2022-02-10 11:23:15
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -56,6 +56,7 @@ class ErpConsoleModel():
 
         while True:
             try:
+                time.sleep(0.1)
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
@@ -125,7 +126,8 @@ class ErpConsoleModel():
         data["county"] = prize_order_dict["county"]
         data["street"] = prize_order_dict["street"]
         data["address"] = prize_order_dict["address"]
-        data["remark"] = prize_order_dict["buyer_remark"]
+        data["remark"] = prize_order_dict["seller_remark"]
+        data["buyer_remark"] = prize_order_dict["buyer_remark"]
         data["timestamp"] = TimeHelper.get_now_timestamp(True)
         data["order_status"] = prize_order_dict["order_status"]
         if data["order_status"] == 2:
@@ -182,6 +184,7 @@ class ErpConsoleModel():
         project_name = config.get_value("project_name", 0)
         while True:
             try:
+                time.sleep(0.1)
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
