@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-01-14 14:15:03
+@LastEditTime: 2022-02-10 11:29:41
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -60,9 +60,21 @@ class StatConsoleModel():
         stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
         stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
         stat_orm_model = StatOrmModel()
+        instance_date = TimeHelper.get_now_format_time()
         print(f"{TimeHelper.get_now_format_time()} 统计队列{mod_value}启动")
+
         while True:
             try:
+                time.sleep(0.1)
+                if abs(TimeHelper.difference_hours(instance_date, TimeHelper.get_now_format_time())) >= 2:
+                    db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+                    stat_queue_model = StatQueueModel(sub_table=sub_table, db_transaction=db_transaction)
+                    del_stat_queue_sub_table = sub_table + "_del" if sub_table else "del"
+                    del_stat_queue_model = StatQueueModel(sub_table=del_stat_queue_sub_table, db_transaction=db_transaction)
+                    stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
+                    stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
+                    stat_orm_model = StatOrmModel()
+                    instance_date = TimeHelper.get_now_format_time()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     stat_queue_list = stat_queue_model.get_list(f"process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
@@ -120,7 +132,7 @@ class StatConsoleModel():
                                     stat_report_model.add_entity(stat_report)
                                 else:
                                     stat_report_model.update_table(f"key_value=key_value+{stat_queue.key_value}", stat_report_condition, params=stat_report_param)
-                            stat_log_model.add_entity(stat_log)
+                                stat_log_model.add_entity(stat_log)
                             stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
                             del_stat_queue_model.add_entity(stat_queue)
                             db_transaction.commit_transaction()
@@ -155,11 +167,17 @@ class StatConsoleModel():
         """
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         stat_orm_model = StatOrmModel()
-        redis_init = SevenHelper.redis_init()
+        instance_date = TimeHelper.get_now_format_time()
         print(f"{TimeHelper.get_now_format_time()} 统计队列{mod_value}启动")
+
         while True:
             try:
-                stat_queue_json = redis_init.lpop(f"stat_queue_list:{mod_value}")
+                time.sleep(0.1)
+                if abs(TimeHelper.difference_hours(instance_date, TimeHelper.get_now_format_time())) >= 2:
+                    db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+                    stat_orm_model = StatOrmModel()
+                    instance_date = TimeHelper.get_now_format_time()
+                stat_queue_json = SevenHelper.redis_init().lpop(f"stat_queue_list:{mod_value}")
                 if not stat_queue_json:
                     time.sleep(1)
                     continue
@@ -201,8 +219,8 @@ class StatConsoleModel():
                     stat_report_param = [stat_queue_dict["app_id"], stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"], create_day_int]
                     stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
 
-                    db_transaction.begin_transaction()
                     if is_add:
+                        db_transaction.begin_transaction()
                         if stat_report_total == 0:
                             stat_report = StatReport()
                             stat_report.app_id = stat_queue_dict["app_id"]
@@ -218,15 +236,15 @@ class StatConsoleModel():
                         else:
                             key_value = stat_queue_dict["key_value"]
                             stat_report_model.update_table(f"key_value=key_value+{key_value}", stat_report_condition, params=stat_report_param)
-                    stat_log_model.add_entity(stat_log)
-                    db_transaction.commit_transaction()
+                        stat_log_model.add_entity(stat_log)
+                        db_transaction.commit_transaction()
 
                 except Exception as ex:
                     if db_transaction.is_transaction == True:
                         db_transaction.rollback_transaction()
                     stat_queue_dict["process_count"] += 1
                     if stat_queue_dict["process_count"] <= 10:
-                        redis_init.rpush(f"stat_queue_list:{mod_value}", SevenHelper.json_dumps(stat_queue_dict))
+                        SevenHelper.redis_init().rpush(f"stat_queue_list:{mod_value}", SevenHelper.json_dumps(stat_queue_dict))
                     else:
                         logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
                     continue
