@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2022-01-12 15:30:28
+@LastEditTime: 2022-01-24 11:03:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -217,7 +217,7 @@ class FrameBaseModel():
 
         user_info_model = UserInfoModel(context=self.context)
         id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
-        user_info_dict = user_info_model.get_cache_dict("id_md5=%s",params=[id_md5],dependency_key=f"user_info:actid_{act_id}_idmd5_{id_md5}")
+        user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=f"user_info:actid_{act_id}_idmd5_{id_md5}")
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "no_user"
@@ -239,7 +239,7 @@ class FrameBaseModel():
             invoke_result_data.error_message = "不是新用户"
             return invoke_result_data
         if check_user_nick == True:
-            if not user_info_dict["user_nick"]:
+            if not user_info_dict["user_nick"] and not user_info_dict["user_nick_encrypt"]:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "no_authorize"
                 invoke_result_data.error_message = "对不起,请先授权"
