@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-12-20 16:07:52
-@LastEditTime: 2022-01-13 14:53:11
+@LastEditTime: 2022-02-15 15:19:19
 @LastEditors: HuangJianYi
 @Description: 中台接口相关处理业务模型
 """
@@ -19,7 +19,7 @@ class MPBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def get_project_code_list(self, project_code):
+    def get_public_function_list(self, project_code):
         """
         :description:  获取公共功能列表
         :param project_code:收费项目代码（服务管理-收费项目列表）
@@ -27,41 +27,41 @@ class MPBaseModel():
         :last_editors: HuangJianYi
         """
 
-        project_code_list = []
+        public_function_list = []
         if not project_code:
-            return project_code_list
+            return public_function_list
         #产品id
         product_id = config.get_value("project_name")
         if not product_id:
-            return project_code_list
-        requst_url = "http://taobao-mp-s.gao7.com/general/project_code_list"
+            return public_function_list
+        requst_url = config.get_value("mp_url","http://taobao-mp-s.gao7.com") + "/general/project_code_list"
         data = {}
         data["project_code"] = project_code
         data["product_id"] = product_id
         result = HTTPHelper.get(requst_url, data, {"Content-Type": "application/json"})
         if result and result.ok and result.text:
             obj_data = SevenHelper.json_loads(result.text)
-            project_code_list = obj_data["Data"]
-        return project_code_list
+            public_function_list = obj_data["Data"]
+        return public_function_list
 
-    def get_shop_config_list(self, store_user_nick):
+    def get_custom_function_list(self, store_user_nick):
         """
-        :description:  获取店铺配置列表
+        :description:  获取定制功能列表
         :param store_user_nick:商家主账号昵称
         :return list: 
         :last_editors: HuangJianYi
         """
-        shop_config_list = []
+        custom_function_list = []
         #产品id
         product_id = config.get_value("project_name")
         if not product_id:
-            return shop_config_list
-        requst_url = "http://taobao-mp-s.gao7.com/custom/query_skin_managemen_list"
+            return custom_function_list
+        requst_url = config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/custom/query_skin_managemen_list"
         data = {}
         data["product_id"] = product_id
         data["store_user_nick"] = store_user_nick
         result = HTTPHelper.get(requst_url, data, {"Content-Type": "application/json"})
         if result and result.ok and result.text:
             obj_data = SevenHelper.json_loads(result.text)
-            shop_config_list = obj_data["Data"]
-        return shop_config_list
\ No newline at end of file
+            custom_function_list = obj_data["Data"]
+        return custom_function_list
\ No newline at end of file
