@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-01-13 15:09:34
+@LastEditTime: 2022-02-25 10:07:12
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -64,7 +64,7 @@ class OrderBaseModel(FrameBaseModel):
         except Exception as ex:
             pass
 
-    def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[]):
+    def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None):
         """
         :description: 用户奖品订单列表
         :param app_id：应用标识
@@ -87,6 +87,7 @@ class OrderBaseModel(FrameBaseModel):
         :param is_cache：是否缓存
         :param condition：条件
         :param params：参数化数组
+        :param prize_roster_sub_table：奖品记录分表名称       
         :return: PageInfo
         :last_editors: HuangJianYi
         """
@@ -139,7 +140,7 @@ class OrderBaseModel(FrameBaseModel):
         else:
             page_list, total = prize_order_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         if is_search_roster == True:
-            prize_roster_model = PrizeRosterModel(context=self.context)
+            prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
             if page_list and len(page_list)>0:
                 order_no_list = [str(i['order_no']) for i in page_list]
                 prize_roster_list_dict = prize_roster_model.get_dict_list(SevenHelper.get_condition_by_str_list("order_no",order_no_list))
@@ -149,7 +150,7 @@ class OrderBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
-    def update_prize_order_status(self,app_id,prize_order_id,order_status,express_company="",express_no=""):
+    def update_prize_order_status(self,app_id,prize_order_id,order_status,express_company="",express_no="",prize_roster_sub_table=None):
         """
         :description: 更新用户奖品订单状态
         :param app_id：应用标识
@@ -157,13 +158,14 @@ class OrderBaseModel(FrameBaseModel):
         :param order_status：订单状态
         :param express_company：快递公司
         :param express_no：快递单号
+        :param prize_roster_sub_table：奖品记录分表名称
         :return: 实体模型InvokeResultData
         :last_editors: HuangJianYi
         """
         now_datetime = SevenHelper.get_now_datetime()
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        prize_order_model = PrizeOrderModel(context=self.context,db_transaction=db_transaction)
-        prize_roster_model = PrizeRosterModel(context=self.context,db_transaction=db_transaction)
+        prize_order_model = PrizeOrderModel(context=self.context, db_transaction=db_transaction)
+        prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table, db_transaction=db_transaction)
         invoke_result_data = InvokeResultData()
 
         prize_order = prize_order_model.get_entity_by_id(prize_order_id)
@@ -244,7 +246,7 @@ class OrderBaseModel(FrameBaseModel):
         prize_order_model.update_table("seller_remark=%s,modify_date=%s", "id=%s", [seller_remark, now_datetime, prize_order_id])
         return invoke_result_data
 
-    def import_prize_order(self,app_id,act_id,content_type,content,ref_head_name='小程序订单号'):
+    def import_prize_order(self, app_id, act_id, content_type, content, ref_head_name='小程序订单号', prize_roster_sub_table=None):
         """
         :description: 
         :param app_id：应用标识
@@ -252,6 +254,7 @@ class OrderBaseModel(FrameBaseModel):
         :param content_type：内容类型 1-base64字符串内容 2-json字符串内容
         :param content：字符串内容
         :param ref_head_name：关联表头名称
+        :param prize_roster_sub_table：奖品记录分表名称
         :return 
         :last_editors: HuangJianYi
         """
@@ -262,7 +265,7 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="无效活动,无法导入订单"
             return invoke_result_data
         prize_order_model = PrizeOrderModel(context=self.context)
-        prize_roster_model = PrizeRosterModel(context=self.context)
+        prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
         data = []
         total_num = 0
         if content_type == 1:
@@ -298,9 +301,9 @@ class OrderBaseModel(FrameBaseModel):
             # 数据导入
             for i in range(1, data_total):
                 row = data[i]
-                order_no = row[order_no_index]
-                express_no = row[express_no_index]
-                express_company = row[express_company_index]
+                order_no = str(row[order_no_index]).strip()
+                express_no = str(row[express_no_index]).strip()
+                express_company = str(row[express_company_index]).strip()
                 if order_no and express_no and express_company:
                     now_datetime = SevenHelper.get_now_datetime()
                     update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
@@ -313,9 +316,9 @@ class OrderBaseModel(FrameBaseModel):
         else:
             data = SevenHelper.json_loads(content)
             for row in data:
-                order_no = row[ref_head_name]
-                express_no = row['物流单号']
-                express_company = row['物流公司']
+                order_no = str(row[ref_head_name]).strip()
+                express_no = str(row['物流单号']).strip()
+                express_company = str(row['物流公司']).strip()
                 if order_no and express_no and express_company:
                     now_datetime = SevenHelper.get_now_datetime()
                     update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
@@ -404,9 +407,9 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="无效活动,无法创建订单"
             return invoke_result_data
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self)
-        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction, context=self)
-        prize_order_model = PrizeOrderModel(db_transaction=db_transaction, context=self)
+        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context)
+        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction, context=self.context)
+        prize_order_model = PrizeOrderModel(db_transaction=db_transaction, context=self.context)
         prize_ids_list = []
         if prize_ids:
             prize_ids_list = prize_ids.split(',')
@@ -420,7 +423,7 @@ class OrderBaseModel(FrameBaseModel):
                     return invoke_result_data
 
         #获取用户信息
-        user_info_dict = user_info_model.get_dict("act_id=%s and user_id=%s", params=[act_id, user_id])
+        user_info_dict = user_info_model.get_dict("act_id=%s and user_id=%s", limit="1", params=[act_id, user_id])
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -561,7 +564,7 @@ class OrderBaseModel(FrameBaseModel):
         acquire_lock_name = f"sync_tao_pay_order:{act_id}_{module_id}_{user_id}"
         identifier = ""
         try:
-            invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,True,check_user_nick,continue_request_expire,acquire_lock_name)
+            invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,False,check_user_nick,continue_request_expire,acquire_lock_name)
             if invoke_result_data.success == True:
                 act_info_dict = invoke_result_data.data["act_info_dict"]
                 act_module_dict = invoke_result_data.data["act_module_dict"]
@@ -617,6 +620,7 @@ class OrderBaseModel(FrameBaseModel):
                         try:
                             #判断是否已经加过奖励
                             if order["oid"] not in pay_order_no_list:
+                                asset_object_name = ""
                                 asset_object_id = ""
                                 payment = round(decimal.Decimal(order["payment"] if order["payment"] else decimal.Decimal(order["price"]) * int(order["num"])), 2)
                                 if asset_type == 3:
@@ -630,6 +634,7 @@ class OrderBaseModel(FrameBaseModel):
                                     if not now_price_gear_dict:
                                         continue
                                     asset_object_id = now_price_gear_dict["id"]
+                                    asset_object_name = now_price_gear_dict["price_gear_name"]
                                 else:
                                     if str(goods_id) != str(order["num_iid"]):
                                         continue
@@ -657,6 +662,7 @@ class OrderBaseModel(FrameBaseModel):
                                 tao_pay_order.create_date = SevenHelper.get_now_datetime()
                                 tao_pay_order.asset_type = asset_type
                                 tao_pay_order.asset_object_id = asset_object_id
+                                tao_pay_order.asset_object_name = asset_object_name
                                 tao_pay_order.surplus_count = order['num']
                                 tao_pay_order.pay_date = order['pay_time']
                                 tao_pay_order_list.append(tao_pay_order)
@@ -879,6 +885,7 @@ class OrderBaseModel(FrameBaseModel):
                     if not false_act_prize:
                         continue
                     prize_roster = {}
+                    user_nick = ""
                     if user_info_list_dict[i]["user_nick"]:
                         length = len(user_info_list_dict[i]["user_nick"])
                         if length > 2:
