@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:26:29
-@LastEditTime: 2021-12-21 17:59:51
+@LastEditTime: 2022-01-13 14:56:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -17,8 +17,10 @@ class PriceBaseModel():
     """
     :description: 价格档位业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None,logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def _delete_price_gear_dependency_key(self,act_id):
         """
