@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-01-11 14:21:42
+@LastEditTime: 2022-01-13 14:57:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -17,8 +17,10 @@ class StatBaseModel(FrameBaseModel):
     """
     :description: 统计上报业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None,logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
         super(StatBaseModel,self).__init__(context)
 
     def add_stat(self, app_id, act_id, module_id, user_id, open_id, key_name, key_value):
@@ -335,7 +337,10 @@ class StatBaseModel(FrameBaseModel):
                 key_list_dict["BeInvitedCount"] = 1  #从分享进入次数
                 stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, open_id, key_list_dict)
         except Exception as ex:
-            self.context.logging_link_error("【处理邀请上报】" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("【处理邀请上报】" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("【处理邀请上报】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
@@ -375,7 +380,10 @@ class StatBaseModel(FrameBaseModel):
                     stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
 
         except Exception as ex:
-            self.context.logging_link_error("【处理分享上报】" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("【处理分享上报】" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("【处理分享上报】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
