@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-01-13 14:43:56
+@LastEditTime: 2022-02-23 17:33:57
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -115,10 +115,11 @@ class TopBaseModel():
             req.template_version = template_version
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【小程序实例化】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序实例化】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序实例化】")
+                    self.logging_link_info(log_info)
 
             #录入数据库
             result_app = resp["miniapp_template_instantiate_response"]
@@ -200,10 +201,11 @@ class TopBaseModel():
             req.template_version = client_ver
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【app更新】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app更新】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app更新】")
+                    self.logging_link_info(log_info)
             if resp and ("miniapp_template_updateapp_response" in resp.keys()):
                 app_version = resp["miniapp_template_updateapp_response"]["app_version"]
                 invoke_result_data = self.online_app(app_id, client_template_id, client_ver, app_version, access_token, app_key, app_secret, is_log)
@@ -253,10 +255,11 @@ class TopBaseModel():
             req.num_iids = num_iids
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取sku名称】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取sku名称】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取sku名称】")
+                    self.logging_link_info(log_info)
             if "items_seller_list_get_response" in resp.keys():
                 if "items" in resp["items_seller_list_get_response"].keys():
                     props_names = resp["items_seller_list_get_response"]["items"]["item"][0]["props_name"].split(';')
@@ -308,10 +311,11 @@ class TopBaseModel():
             req.tid = order_no
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取单笔订单】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单笔订单】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单笔订单】")
+                    self.logging_link_info(log_info)
             if "open_trade_get_response" in resp.keys():
                 if "trade" in resp["open_trade_get_response"]:
                     invoke_result_data.data = resp["open_trade_get_response"]["trade"]
@@ -375,10 +379,11 @@ class TopBaseModel():
             while has_next:
                 resp = req.getResponse(access_token)
                 if is_log:
+                    log_info = str(resp) + "【access_token】：" + access_token + "【获取购买订单】"
                     if self.context:
-                        self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取购买订单】")
+                        self.context.logging_link_info(log_info)
                     elif self.logging_link_info:
-                        self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取购买订单】")
+                        self.logging_link_info(log_info)
                 if "open_trades_sold_get_response" in resp.keys():
                     if "trades" in resp["open_trades_sold_get_response"].keys():
                         all_order = all_order + resp["open_trades_sold_get_response"]["trades"]["trade"]
@@ -409,7 +414,7 @@ class TopBaseModel():
     def get_refund_order_list(self, buyer_nick, access_token,app_key, app_secret, start_modified="", end_modified="",page_size=50,is_log=False):
         """
         :description: 获取淘宝退款订单
-        :param open_id：open_id
+        :param buyer_nick：用户昵称
         :param access_token：access_token
         :param app_key:app_key
         :param app_secret:app_secret
@@ -444,10 +449,11 @@ class TopBaseModel():
             while has_next:
                 resp = req.getResponse(access_token)
                 if is_log:
+                    log_info = str(resp) + "【access_token】：" + access_token + "【获取退单订单】"
                     if self.context:
-                        self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取退单订单】")
+                        self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取退单订单】")
+                    self.logging_link_info(log_info)
                 if "refunds_receive_get_response" in resp.keys():
                     if "refunds" in resp["refunds_receive_get_response"].keys():
                         all_order = all_order + resp["refunds_receive_get_response"]["refunds"]["refund"]
@@ -501,10 +507,11 @@ class TopBaseModel():
             req.app_version = app_version
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【app上线】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app上线】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app上线】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -543,10 +550,11 @@ class TopBaseModel():
             req.fields = "sid,title,pic_path"
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取店铺信息】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取店铺信息】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取店铺信息】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -585,10 +593,11 @@ class TopBaseModel():
             req.fields = "user_id,nick,sex"
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -623,20 +632,14 @@ class TopBaseModel():
         """
         invoke_result_data = InvokeResultData()
         try:
-            top.setDefaultAppInfo(app_key, app_secret)
-            req = top.api.VasSubscribeGetRequest()
-            req.article_code = config.get_value("article_code")
-            req.nick = user_nick
-            resp = req.getResponse(access_token)
-            if is_log:
-                if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取订购过期时间】")
-                elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取订购过期时间】")
-            if "article_user_subscribe" not in resp["vas_subscribe_get_response"]["article_user_subscribes"].keys():
+            vas_subscribe_get_response = self.get_vas_subscribe(user_nick, access_token, app_key, app_secret, is_log)
+            if not vas_subscribe_get_response:
                 invoke_result_data.data = "expire"
                 return invoke_result_data
-            invoke_result_data.data = resp["vas_subscribe_get_response"]["article_user_subscribes"]["article_user_subscribe"][0]["deadline"]
+            if "article_user_subscribe" not in vas_subscribe_get_response["article_user_subscribes"].keys():
+                invoke_result_data.data = "expire"
+                return invoke_result_data
+            invoke_result_data.data = vas_subscribe_get_response["article_user_subscribes"]["article_user_subscribe"][0]["deadline"]
             return invoke_result_data
         except Exception as ex:
             if self.context:
@@ -683,10 +686,11 @@ class TopBaseModel():
                 req.num_iids = cur_num_iids
                 resp = req.getResponse(access_token)
                 if is_log:
+                    log_info = str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】"
                     if self.context:
-                        self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】")
+                        self.context.logging_link_info(log_info)
                     elif self.logging_link_info:
-                        self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】")
+                        self.logging_link_info(log_info)
 
                 if "items_seller_list_get_response" in resp.keys():
                     if "items" in resp["items_seller_list_get_response"].keys():
@@ -747,10 +751,11 @@ class TopBaseModel():
                 req.order_by = order_tag + ":" + order_by
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】")
+                    self.logging_link_info(log_info)
             if resp:
                 resp["pageSize"] = page_size
                 resp["pageIndex"] = page_index
@@ -796,10 +801,11 @@ class TopBaseModel():
             req.num_iid = num_iid
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -854,10 +860,11 @@ class TopBaseModel():
                 resp["pageSize"] = page_size
                 resp["pageIndex"] = page_index
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -902,10 +909,11 @@ class TopBaseModel():
             req.add_bind = status
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【小程序投放商品】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序投放商品】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序投放商品】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -947,10 +955,11 @@ class TopBaseModel():
             req.award_type = "1"
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -995,10 +1004,11 @@ class TopBaseModel():
             req.app_name = "promotioncenter-" + config.get_value("server_template_id")
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【发放优惠劵】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【发放优惠劵】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【发放优惠劵】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -1042,10 +1052,11 @@ class TopBaseModel():
                 req.nick = nick
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -1108,10 +1119,11 @@ class TopBaseModel():
             req.extra_info = "{\"source\":\"isvapp\",\"activityId\":\"\",\"entrance\":\"hudong\"}"
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】")
+                    self.logging_link_info(log_info)
             if "crm_member_joinurl_get_response" in resp.keys():
                 if "result" in resp["crm_member_joinurl_get_response"].keys():
                     if "result" in resp["crm_member_joinurl_get_response"]["result"].keys():
@@ -1157,10 +1169,11 @@ class TopBaseModel():
             req.miniapp_id = app_id
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单查询】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单查询】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单查询】")
+                    self.logging_link_info(log_info)
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
@@ -1206,10 +1219,11 @@ class TopBaseModel():
             req.limit_num = 1
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】")
+                    self.logging_link_info(log_info)
             if resp and resp["opentrade_special_users_mark_response"]["result"] == 1:
                 #  ------------ TopOpentradeSpecialUserMark: {'opentrade_special_users_mark_response': {'result': 1, 'request_id': 'rsk23xhlk310'}}
                 invoke_result_data.data = True
@@ -1257,10 +1271,11 @@ class TopBaseModel():
             req.item_ids = str(goods_id)
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】")
+                    self.logging_link_info(log_info)
             # {'opentrade_special_items_bind_response': {'results': {'item_bind_result': [{'bind_ok': False, 'error_message': '商品已绑定到小程序:情之缘1993_好货跳一跳_[3000000029278805]', 'item_id': 632007280726}]}, 'request_id': 'zrq8mt8d8xdo'}}
             if resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]:
                 if not resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]["bind_ok"]:
@@ -1290,34 +1305,64 @@ class TopBaseModel():
     def get_project_code(self, user_nick, access_token,app_key, app_secret,is_log=False):
         """
         :description: 获取项目编码
-        :param user_nick：access_token
+        :param user_nick：用户昵称
         :param access_token：access_token
         :param app_key:app_key
         :param app_secret:app_secret
         :param is_log：是否记录返回信息
-        :return 字符串
+        :return list
         :last_editors: HuangJianYi
         """
         try:
+            vas_subscribe_get_response = self.get_vas_subscribe(user_nick, access_token, app_key, app_secret, is_log)
+            if not vas_subscribe_get_response:
+                return ""
+            if "article_user_subscribe" not in vas_subscribe_get_response["article_user_subscribes"].keys():
+                return ""
+            return vas_subscribe_get_response["article_user_subscribes"]["article_user_subscribe"][0]["item_code"]
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            return ""
+
+    def get_vas_subscribe(self, user_nick, access_token,app_key, app_secret,is_log=False):
+        """
+        :description:订购关系查询 用于ISV根据登录进来的淘宝会员名查询该为该会员开通哪些收费项目，ISV只能查询自己名下的应用及收费项目的订购情况
+        :param user_nick：用户昵称
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return 订购关系
+        :last_editors: HuangJianYi
+        """
+        try:
+            redis_init = SevenHelper.redis_init()
+            cache_key = f"get_vas_subscribe:{user_nick}"
+            vas_subscribe_get_response = redis_init.get(cache_key)
+            if vas_subscribe_get_response:
+                return json.loads(vas_subscribe_get_response)
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.VasSubscribeGetRequest()
             req.article_code = config.get_value("article_code")
             req.nick = user_nick
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【订购关系查询】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取项目编码】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取项目编码】")
-            if "article_user_subscribe" not in resp["vas_subscribe_get_response"]["article_user_subscribes"].keys():
-                return "expire"
-            return resp["vas_subscribe_get_response"]["article_user_subscribes"]["article_user_subscribe"][0]["item_code"]
+                    self.logging_link_info(log_info)
+            redis_init.set(cache_key, json.dumps(resp["vas_subscribe_get_response"]),5)
+            return resp["vas_subscribe_get_response"]
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error(traceback.format_exc())
             elif self.logging_link_error:
                 self.logging_link_error(traceback.format_exc())
-            return "expire"
+            return None
 
     def get_short_url(self, url, access_token, app_key, app_secret, is_log=False):
         """
@@ -1338,10 +1383,11 @@ class TopBaseModel():
             req.miniapp_url = url
             resp = req.getResponse(access_token)
             if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【获取短链接】"
                 if self.context:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取短链接】")
+                    self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
-                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取短链接】")
+                    self.logging_link_info(log_info)
             if "miniapp_shorturl_create_response" not in  resp:
                 invoke_result_data.success = False
                 return invoke_result_data
@@ -1363,3 +1409,115 @@ class TopBaseModel():
                 self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             return invoke_result_data
+
+    def get_crm_point_available(self, user_nick, access_token, app_key, app_secret, is_log=False):
+        """
+        :description: 获取店铺会员积分
+        :param user_nick：用户昵称
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return 返回店铺会员积分
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.CrmPointAvailableGetRequest()
+            req.buyer_nick = user_nick
+            resp = req.getResponse(access_token)
+            if is_log:
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) +  "【access_token】：" + access_token + "【获取店铺会员积分】"
+                if self.context:
+                    self.context.logging_link_info(log_info)
+                elif self.logging_link_info:
+                    self.logging_link_info(log_info)
+            if "crm_point_available_get_response" not in  resp:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if "result" not in resp["crm_point_available_get_response"]:
+                invoke_result_data.success = False
+                return invoke_result_data
+            invoke_result_data.data = resp["crm_point_available_get_response"]["result"]
+            return invoke_result_data
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            invoke_result_data.success = False
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        invoke_result_data.error_code = "no_power"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+                    if "submsg=" in content:
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+            return invoke_result_data
+
+    def change_crm_point(self, open_id, change_type, opt_type, quantity, access_token, app_key, app_secret, activity_id=0, activity_name="", is_log=False):
+        """
+        :description: 操作店铺会员积分
+        :param open_id：买家open_id
+        :param change_type：变更类型：0交易，1：互动活动，2：权益兑换，3：手工调整
+        :param opt_type：操作类型，0：增加，1：扣减
+        :param quantity：积分数量
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param activity_id：活动Id
+        :param activity_name：活动名称
+        :param is_log：是否记录返回信息
+        :return 返回操作结果
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.CrmPointChangeRequest()
+            if activity_id > 0:
+                req.activity_id = activity_id
+            if activity_name:
+                req.activity_name = activity_name
+            req.change_type = change_type
+            req.opt_type = opt_type
+            req.quantity = quantity
+            req.open_id = open_id
+            resp = req.getResponse(access_token)
+            if is_log:
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) + "【access_token】：" + access_token + "【操作店铺会员积分】"
+                if self.context:
+                    self.context.logging_link_info(log_info)
+                elif self.logging_link_info:
+                    self.logging_link_info(log_info)
+            if "crm_point_change_response" not in resp:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if "result" not in resp["crm_point_change_response"]:
+                invoke_result_data.success = False
+                return invoke_result_data
+            invoke_result_data.data = resp["crm_point_change_response"]["result"]
+            return invoke_result_data
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            invoke_result_data.success = False
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        invoke_result_data.error_code = "no_power"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+                    if "submsg=" in content:
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+            return invoke_result_data
\ No newline at end of file
