@@ -2,11 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-01-13 15:08:19
+@LastEditTime: 2022-02-24 13:34:14
 @LastEditors: HuangJianYi
 @Description: 
 """
 
+from seven_cloudapp_frame.libs.customize.cryptography_helper import CryptographyHelper
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
@@ -18,6 +19,7 @@ from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 from seven_cloudapp_frame.models.db_models.user.user_address_model import *
 
+
 class UserBaseModel(FrameBaseModel):
     """
     :description: 用户信息业务模型
@@ -26,7 +28,7 @@ class UserBaseModel(FrameBaseModel):
         self.context = context
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
-        super(UserBaseModel,self).__init__(context)
+        super(UserBaseModel, self).__init__(context)
 
     def _get_user_info_id_md5(self, act_id, user_id):
         """
@@ -50,7 +52,7 @@ class UserBaseModel(FrameBaseModel):
         """
         return f"user_black:{act_id}_{user_id}"
 
-    def _delete_user_black_cache(self,act_id,user_id):
+    def _delete_user_black_cache(self, act_id, user_id):
         """
         :description: 删除用户黑名单缓存
         :param act_id：活动标识
@@ -58,7 +60,7 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        cache_key = self.get_user_black_dependency_key(act_id,user_id)
+        cache_key = self.get_user_black_dependency_key(act_id, user_id)
         redis_init = SevenHelper.redis_init()
         redis_init.delete(cache_key)
 
@@ -72,11 +74,11 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         if id_md5:
-            return  f"user_info:actid_{act_id}_idmd5_{id_md5}"
+            return f"user_info:actid_{act_id}_idmd5_{id_md5}"
         else:
-            return  f"user_info:actid_{act_id}_openid_{open_id}"
+            return f"user_info:actid_{act_id}_openid_{open_id}"
 
-    def _delete_user_info_cache(self,act_id,id_md5):
+    def _delete_user_info_cache(self, act_id, id_md5):
         """
         :description: 删除用户信息缓存
         :param act_id：活动标识
@@ -84,11 +86,11 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        cache_key = self.get_user_info_dependency_key(act_id,id_md5)
+        cache_key = self.get_user_info_dependency_key(act_id, id_md5)
         redis_init = SevenHelper.redis_init()
         redis_init.delete(cache_key)
 
-    def get_user_info_dict(self,app_id, act_id, user_id,open_id="",is_cache=True):
+    def get_user_info_dict(self, app_id, act_id, user_id, open_id="", is_cache=True):
         """
         :description: 获取用户信息单条记录
         :param app_id：应用标识
@@ -102,18 +104,18 @@ class UserBaseModel(FrameBaseModel):
         if not act_id or (not user_id and not open_id):
             return user_info_dict
         user_info_model = UserInfoModel(context=self.context)
-        id_md5 = self._get_user_info_id_md5(act_id,user_id)
-        dependency_key = self.get_user_info_dependency_key(act_id,id_md5,open_id)
+        id_md5 = self._get_user_info_id_md5(act_id, user_id)
+        dependency_key = self.get_user_info_dependency_key(act_id, id_md5, open_id)
         if id_md5:
             if is_cache:
-                user_info_dict = user_info_model.get_cache_dict("id_md5=%s",params=[id_md5],dependency_key=dependency_key)
+                user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=dependency_key)
             else:
-                user_info_dict = user_info_model.get_dict("id_md5=%s",params=[id_md5])
+                user_info_dict = user_info_model.get_dict("id_md5=%s", limit="1", params=[id_md5])
         else:
             if is_cache:
-                user_info_dict = user_info_model.get_cache_dict(dependency_key=dependency_key,where="act_id=%s and open_id=%s", params=[act_id, open_id])
+                user_info_dict = user_info_model.get_cache_dict(where="act_id=%s and open_id=%s", limit="1", params=[act_id, open_id], dependency_key=dependency_key)
             else:
-                user_info_dict = user_info_model.get_dict("act_id=%s and open_id=%s", params=[act_id, open_id])
+                user_info_dict = user_info_model.get_dict("act_id=%s and open_id=%s", limit="1", params=[act_id, open_id])
 
         if user_info_dict and user_info_dict["app_id"] != app_id:
             user_info_dict = None
@@ -166,7 +168,7 @@ class UserBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
-    def get_join_member_url(self,access_token,app_key,app_secret,is_log):
+    def get_join_member_url(self, access_token, app_key, app_secret, is_log):
         """
         :description: 获取加入会员地址
         :param access_token:access_token
@@ -177,7 +179,7 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         top_base_model = TopBaseModel(context=self.context)
-        return top_base_model.get_join_member_url(access_token,app_key,app_secret,is_log)
+        return top_base_model.get_join_member_url(access_token, app_key, app_secret, is_log)
 
     def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id=""):
         """
@@ -211,21 +213,24 @@ class UserBaseModel(FrameBaseModel):
         user_info_model = UserInfoModel(context=self.context)
         now_datetime = SevenHelper.get_now_datetime()
         try:
-            user_account = user_account_model.get_entity("open_id=%s",params=[open_id])
+            user_account = user_account_model.get_entity("open_id=%s", params=[open_id])
             if not user_account:
                 user_account = UserAccount()
                 user_account.union_id = union_id
                 user_account.open_id = open_id
-                user_account.user_nick = user_nick
+                user_account.user_nick = CryptographyHelper.emoji_to_emoji_base64(user_nick)
+                user_account.user_nick_encrypt = CryptographyHelper.base64_encrypt(user_nick) if user_nick else ""
                 user_account.avatar = avatar
                 user_account.user_state = 0
                 user_account.create_date = now_datetime
                 user_account.modify_date = now_datetime
                 user_account.id = user_account_model.add_entity(user_account)
             else:
-                user_account.user_nick = user_nick if user_nick and user_account.user_nick != user_nick else user_account.user_nick
+                if user_nick and user_account.user_nick != user_nick:
+                    user_account.user_nick = CryptographyHelper.emoji_to_emoji_base64(user_nick)
+                    user_account.user_nick_encrypt = CryptographyHelper.base64_encrypt(user_nick)
                 user_account.avatar = avatar if avatar and user_account.avatar != avatar else user_account.avatar
-                user_account_model.update_entity(user_account, "user_nick,avatar")
+                user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,avatar")
 
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
@@ -237,8 +242,8 @@ class UserBaseModel(FrameBaseModel):
                 user_info.user_id = user_account.id
                 user_info.is_new = 1
                 user_info.user_nick = user_account.user_nick
+                user_info.user_nick_encrypt = user_account.user_nick_encrypt
                 user_info.avatar = user_account.avatar
-                user_info.user_nick = user_nick if user_nick else user_info.user_nick
                 user_info.avatar = avatar if avatar else user_info.avatar
                 user_info.is_auth = 0 if not user_info.user_nick else 1
                 user_info.create_date = now_datetime
@@ -252,6 +257,7 @@ class UserBaseModel(FrameBaseModel):
                     invoke_result_data.error_message = "非法操作"
                     return invoke_result_data
                 user_info.user_nick = user_account.user_nick
+                user_info.user_nick_encrypt = user_account.user_nick_encrypt
                 user_info.avatar = user_account.avatar
                 user_info.is_auth = 0 if not user_info.user_nick else 1
                 # if TimeHelper.difference_minutes(now_datetime,user_info.create_date) > 1:
@@ -259,9 +265,9 @@ class UserBaseModel(FrameBaseModel):
                 user_info.is_new = 0
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
-                user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar,is_auth")
+                user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,user_nick_encrypt,avatar,is_auth")
 
-                self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
+                self._delete_user_info_cache(user_info.act_id, user_info.id_md5)
 
         except Exception as ex:
             if self.context:
@@ -274,7 +280,7 @@ class UserBaseModel(FrameBaseModel):
         invoke_result_data.data = user_info.__dict__
         return invoke_result_data
 
-    def update_user_info(self, app_id, act_id, user_id, open_id, user_nick, avatar,is_member_before=-1,is_favor_before=-1):
+    def update_user_info(self, app_id, act_id, user_id, open_id, user_nick, avatar, is_member_before=-1, is_favor_before=-1):
         """
         :description: 更新用户信息（主要用于授权更新昵称和头像）
         :param app_id：应用标识
@@ -301,7 +307,7 @@ class UserBaseModel(FrameBaseModel):
         user_info_model = UserInfoModel(context=self.context)
 
         try:
-            user_info_dict = self.get_user_info_dict(app_id, act_id, user_id,open_id)
+            user_info_dict = self.get_user_info_dict(app_id, act_id, user_id, open_id)
             if not user_info_dict:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
@@ -313,20 +319,24 @@ class UserBaseModel(FrameBaseModel):
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "非法操作"
                     return invoke_result_data
-                user_info_dict["is_member_before"] = is_member_before if is_member_before!=-1 else user_info_dict["is_member_before"]
-                user_info_dict["is_favor_before"] = is_favor_before if is_favor_before!=-1 else user_info_dict["is_favor_before"]
-                user_info_dict["user_nick"] = user_nick if user_nick else user_info_dict["user_nick"]
+                user_info_dict["is_member_before"] = is_member_before if is_member_before != -1 else user_info_dict["is_member_before"]
+                user_info_dict["is_favor_before"] = is_favor_before if is_favor_before != -1 else user_info_dict["is_favor_before"]
+                if user_nick:
+                    user_info_dict["user_nick"] = CryptographyHelper.emoji_to_emoji_base64(user_nick)
+                    user_info_dict["user_nick_encrypt"] = CryptographyHelper.base64_encrypt(user_nick)
                 user_info_dict["avatar"] = avatar if avatar else user_info_dict["avatar"]
+                user_info_dict["is_auth"] = 1 if user_info_dict["user_nick"] else 0
                 user_info_dict["modify_date"] = SevenHelper.get_now_datetime()
-                user_info_model.update_table("user_nick=%s,avatar=%s,modify_date=%s,is_member_before=%s,is_favor_before=%s","id=%s",params=[user_info_dict["user_nick"],user_info_dict["avatar"],user_info_dict["modify_date"],user_info_dict["is_member_before"],user_info_dict["is_favor_before"],user_info_dict["id"]])
+                user_info_model.update_table("user_nick=%s,user_nick_encrypt=%s,avatar=%s,modify_date=%s,is_auth=%s,is_member_before=%s,is_favor_before=%s", "id=%s", params=[user_info_dict["user_nick"], user_info_dict["user_nick_encrypt"], user_info_dict["avatar"], user_info_dict["modify_date"], user_info_dict["is_auth"], user_info_dict["is_member_before"], user_info_dict["is_favor_before"], user_info_dict["id"]])
 
-                self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
+                self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
 
                 update_sql = ""
                 params = []
                 if user_nick:
-                    update_sql = "user_nick=%s"
-                    params.append(user_nick)
+                    update_sql = "user_nick=%s,user_nick_encrypt=%s"
+                    params.append(CryptographyHelper.emoji_to_emoji_base64(user_nick))
+                    params.append(CryptographyHelper.base64_encrypt(user_nick))
                 if avatar:
                     update_sql += "," if update_sql else ""
                     update_sql += "avatar=%s"
@@ -356,7 +366,7 @@ class UserBaseModel(FrameBaseModel):
         invoke_result_data = InvokeResultData()
         id_md5 = self._get_user_info_id_md5(act_id, user_id)
         user_info_model = UserInfoModel(context=self.context)
-        user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
+        user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -379,25 +389,26 @@ class UserBaseModel(FrameBaseModel):
         user_info.modify_date = modify_date
         user_info_model.update_entity(user_info, "user_state,relieve_date,modify_date")
 
-        self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
+        self._delete_user_info_cache(user_info.act_id, user_info.id_md5)
 
         return invoke_result_data
 
-    def update_user_state_by_black(self,app_id,act_id,user_id):
+    def update_user_state_by_black(self, app_id, act_id, user_id, reason=""):
         """
         :description: 用户拉入黑名单
         :param app_id：应用标识
         :param act_id：活动标识
         :param user_id：用户标识
+        :param reason：拉黑理由
         :return:
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-        user_info_model = UserInfoModel(db_transaction=db_transaction,context=self.context)
+        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
 
-        user_info_dict = self.get_user_info_dict(app_id,act_id,user_id)
+        user_info_dict = self.get_user_info_dict(app_id, act_id, user_id)
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -417,10 +428,10 @@ class UserBaseModel(FrameBaseModel):
         user_info_dict["user_state"] = 1
         user_info_dict["modify_date"] = modify_date
 
-        user_black = user_black_model.get_entity("act_id=%s and user_id=%s", params=[act_id,user_id])
+        user_black = user_black_model.get_entity("act_id=%s and user_id=%s", params=[act_id, user_id])
         try:
             db_transaction.begin_transaction()
-            user_info_model.update_table("user_state=%s,modify_date=%s","id=%s",params=[user_info_dict["user_state"],user_info_dict["modify_date"],user_info_dict["id"]])
+            user_info_model.update_table("user_state=%s,modify_date=%s", "id=%s", params=[user_info_dict["user_state"], user_info_dict["modify_date"], user_info_dict["id"]])
             if not user_black:
                 #添加到用户黑名单管理表
                 user_black = UserBlack()
@@ -431,11 +442,13 @@ class UserBaseModel(FrameBaseModel):
                 user_black.user_nick = user_info_dict["user_nick"]
                 user_black.black_type = 2
                 user_black.refund_order_data = []
+                user_black.reason = reason
                 user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.add_entity(user_black)
             else:
                 user_black.audit_status = 0
                 user_black.black_type = 2
+                user_black.reason = reason
                 user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.update_entity(user_black)
             result = db_transaction.commit_transaction()
@@ -444,9 +457,9 @@ class UserBaseModel(FrameBaseModel):
                 invoke_result_data.error_code = "fail"
                 invoke_result_data.error_message = "系统繁忙,请稍后再试"
                 return invoke_result_data
-            invoke_result_data.data = {"user_info":user_info_dict}
-            self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
-            self._delete_user_black_cache(act_id,user_id)
+            invoke_result_data.data = {"user_info": user_info_dict}
+            self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
+            self._delete_user_black_cache(act_id, user_id)
         except Exception as ex:
             if db_transaction.is_transaction == True:
                 db_transaction.rollback_transaction()
@@ -460,7 +473,7 @@ class UserBaseModel(FrameBaseModel):
 
         return invoke_result_data
 
-    def apply_black_unbind(self,app_id,act_id,user_id, open_id="",reason="误封号,申请解封"):
+    def apply_black_unbind(self, app_id, act_id, user_id, open_id="", reason="误封号,申请解封"):
         """
         :description: 申请黑名单解绑
         :param app_id：应用标识
@@ -476,7 +489,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-        user_info_dict = self.get_user_info_dict(app_id,act_id,user_id,open_id)
+        user_info_dict = self.get_user_info_dict(app_id, act_id, user_id, open_id)
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -494,7 +507,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "账号正常,无需申请解封"
             return invoke_result_data
         user_black_model = UserBlackModel(context=self.context)
-        user_black = user_black_model.get_cache_entity("act_id=%s and user_id=%s", order_by="create_date desc", params=[act_id, user_id],dependency_key=self.get_user_black_dependency_key(act_id,user_id))
+        user_black = user_black_model.get_cache_entity("act_id=%s and user_id=%s", order_by="create_date desc", params=[act_id, user_id], dependency_key=self.get_user_black_dependency_key(act_id, user_id))
         if not user_black:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -509,10 +522,10 @@ class UserBaseModel(FrameBaseModel):
         user_black.audit_status = 1
         user_black.reason = reason
         user_black_model.update_entity(user_black, "audit_status,reason")
-        self._delete_user_black_cache(act_id,user_id)
+        self._delete_user_black_cache(act_id, user_id)
         return invoke_result_data
 
-    def audit_user_black(self,app_id,black_id,audit_status,audit_remark=""):
+    def audit_user_black(self, app_id, black_id, audit_status, audit_remark=""):
         """
         :description: 审核黑名单
         :param app_id：应用标识
@@ -543,7 +556,7 @@ class UserBaseModel(FrameBaseModel):
 
         user_info_model = UserInfoModel(context=self.context)
         id_md5 = self._get_user_info_id_md5(user_black.act_id, user_black.user_id)
-        user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
+        user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -553,15 +566,15 @@ class UserBaseModel(FrameBaseModel):
         condition = "audit_status=%s,audit_date=%s"
         params = [audit_status, audit_date]
         if audit_remark:
-            condition+=",audit_remark=%s"
+            condition += ",audit_remark=%s"
             params.append(audit_remark)
         params.append(black_id)
         if audit_status == 0:
-            condition+=",black_type=2"
+            condition += ",black_type=2"
             user_black_model.update_table(condition, "id=%s", params)
             user_info.user_state = 1
             user_info.modify_date = audit_date
-            user_info_model.update_entity(user_info,"user_state,modify_date")
+            user_info_model.update_entity(user_info, "user_state,modify_date")
         elif audit_status == 2:
             user_black_model.update_table(condition, "id=%s", params)
             user_info.user_state = 0
@@ -571,12 +584,12 @@ class UserBaseModel(FrameBaseModel):
         elif audit_status == 3:
             user_black_model.update_table(condition, "id=%s", params)
 
-        invoke_result_data.data = {"user_info":user_info.__dict__}
-        self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
+        invoke_result_data.data = {"user_info": user_info.__dict__}
+        self._delete_user_info_cache(user_info.act_id, user_info.id_md5)
         self._delete_user_black_cache(user_black.act_id, user_black.user_id)
         return invoke_result_data
 
-    def update_audit_remark(self,app_id,black_id,audit_remark):
+    def update_audit_remark(self, app_id, black_id, audit_remark):
         """
         :description: 修改审核备注
         :param app_id：应用标识
@@ -603,11 +616,11 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
-        user_black_model.update_table("audit_remark=%s", "id=%s", [audit_remark,black_id])
-        self._delete_user_black_cache(black_info.act_id,black_info.user_id)
+        user_black_model.update_table("audit_remark=%s", "id=%s", [audit_remark, black_id])
+        self._delete_user_black_cache(black_info.act_id, black_info.user_id)
         return invoke_result_data
 
-    def get_black_info_dict(self, app_id, act_id, user_id,is_cache=True):
+    def get_black_info_dict(self, app_id, act_id, user_id, is_cache=True):
         """
         :description: 获取黑名单单条记录
         :param app_id：应用标识
@@ -627,9 +640,9 @@ class UserBaseModel(FrameBaseModel):
         params = [act_id, user_id]
         user_black_model = UserBlackModel(context=self.context)
         if is_cache:
-            user_black_dict = user_black_model.get_cache_dict(where=where, params=params,dependency_key=self.get_user_black_dependency_key(act_id,user_id))
+            user_black_dict = user_black_model.get_cache_dict(where=where, limit="1", params=params, dependency_key=self.get_user_black_dependency_key(act_id, user_id))
         else:
-            user_black_dict = user_black_model.get_dict(where, params=params)
+            user_black_dict = user_black_model.get_dict(where, limit="1", params=params)
         return user_black_dict
 
     def get_black_list(self, app_id, act_id, page_size=20, page_index=0, audit_status=-1, user_id=0, start_date="", end_date="", user_nick="", open_id="", order_by="id desc"):
@@ -685,7 +698,7 @@ class UserBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
-    def check_pull_black(self,user_info_dict,is_black,refund_count,all_order_data):
+    def check_pull_black(self, user_info_dict, is_black, refund_count, all_order_data):
         """
         :description: 校验是否拉黑
         :param user_info_dict：用户信息字典
@@ -737,7 +750,7 @@ class UserBaseModel(FrameBaseModel):
                         user_black.refund_order_data = SevenHelper.json_dumps(refund_order_data)
                         user_black.create_date = SevenHelper.get_now_datetime()
                         user_black_model.add_entity(user_black)
-                    self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
+                    self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error("【校验是否拉黑】" + traceback.format_exc())
@@ -746,7 +759,7 @@ class UserBaseModel(FrameBaseModel):
             result = False
         return result
 
-    def get_user_address_list(self, app_id, act_id, user_id,is_cache=True):
+    def get_user_address_list(self, app_id, act_id, user_id, is_cache=True):
         """
         :description: 获取用户地址列表
         :param app_id：应用标识
@@ -796,7 +809,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-        user_info_dict = self.get_user_info_dict(app_id,act_id,user_id,open_id)
+        user_info_dict = self.get_user_info_dict(app_id, act_id, user_id, open_id)
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
