@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-01-06 10:35:33
+@LastEditTime: 2022-02-18 14:12:41
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -39,7 +39,9 @@ def seven_cloudapp_frame_route():
         (r"/client/act_info", act.ActInfoHandler),  #活动信息
         (r"/client/act_prize_list", act.ActPrizeListHandler),  #活动奖品列表
         (r"/client/cms_info_list", act.CmsInfoListHandler),  #位置信息列表
+        (r"/client/price_gear_list", act.PriceGearListHandler),  #价格档位列表
         (r"/client/app_expire", app.AppExpireHandler),  #小程序过期时间
+        (r"/client/get_high_power_list", app.GetHighPowerListHandler),  #获取中台配置的高级权限列表
         (r"/client/add_wechat_subscribe", app.AddWechatSubscribeHandler),  #添加微信订阅次数
         (r"/client/sku_info", goods.SkuInfoHandler),  #sku信息
         (r"/client/goods_list", goods.GoodsListHandler),  #商品列表
@@ -73,16 +75,16 @@ def seven_cloudapp_frame_route():
         (r"/client/trefund_notify", pay.TiktokRefundNotifyHandler),  #抖音退款异步通知
 
         #后台和千牛端
-        (r"/server/saas_custom", base_s.SaasCustomHandler),  #saas定制化信息获取
-        (r"/server/login", user_s.LoginHandler),  #千牛端登录
         (r"/server/left_navigation", base_s.LeftNavigationHandler),  #左侧导航
         (r"/server/friend_link_list", base_s.FriendLinkListHandler),  #获取友情链接产品互推列表
         (r"/server/send_sms", base_s.SendSmsHandler),  #发短信
         (r"/server/cms_info_list", base_s.CmsInfoListHandler),  #位置信息列表
         (r"/server/save_cms_info", base_s.SaveCmsInfoHandler),  #保存位置信息
         (r"/server/get_product_price", base_s.GetProductPriceHandler),  #获取产品价格信息
+        (r"/server/get_high_power_list", app_s.GetHighPowerListHandler),  #获取中台配置的高级权限列表
         (r"/server/app_info", app_s.AppInfoHandler),  #应用信息
-        (r"/server/get_app_id", app_s.GetAppIDHandler),  #根据店铺名称返回应用标识 用于GM工具
+        (r"/server/check_gm_power", app_s.CheckGmPowerHandler),  #根据店铺名称返回应用标识 用于GM工具
+        (r"/server/get_appid_by_gm", app_s.GetAppidByGmHandler),  #获取是否有GM工具权限 用于GM工具
         (r"/server/instantiate", app_s.InstantiateAppHandler),  #实例化小程序
         (r"/server/version_upgrade", app_s.VersionUpgradeHandler),  #小程序端版本升级
         (r"/server/update_telephone", app_s.UpdateTelephoneHandler),  #更新手机号
@@ -120,6 +122,7 @@ def seven_cloudapp_frame_route():
         (r"/server/import_prize_order", order_s.ImportPrizeOrderHandler),  #导入发货订单
         (r"/server/stat_report_list", report_s.StatReportListHandler),  #报表数据列表(表格)
         (r"/server/trend_report_list", report_s.TrendReportListHandler),  #报表数据列表(趋势图)
+        (r"/server/login", user_s.LoginHandler),  #千牛端登录
         (r"/server/user_info_list", user_s.UserInfoListHandler),  #用户信息列表
         (r"/server/update_user_status", user_s.UpdateUserStatusHandler),  #更新用户状态（0正常1黑名单）
         (r"/server/update_user_status_by_black", user_s.UpdateUserStatusByBlackHandler),  #更新用户状态(黑名单管理模式)
